#
# spec file
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif

%{?sle15_python_module_pythons}
Name:           python-typing_extensions%{psuffix}
Version:        4.5.0
Release:        150400.3.5.9
Summary:        Backported and Experimental Type Hints for Python 3.7+
License:        Python-2.0
URL:            https://github.com/python/typing/
Source0:        https://files.pythonhosted.org/packages/source/t/typing_extensions/typing_extensions-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.7}
#BuildRequires:  %{python_module flit-core >= 3.4 with %python-flit-core < 4}
BuildRequires:  %{python_module flit-core}
BuildRequires:  %{python_module pip}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Provides:       python-typing-extensions = %{version}-%{release}
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module testsuite}
%endif
%python_subpackages

%description
The typing_extensions module serves two related purposes:

  * Enable use of new type system features on older Python versions.
    For example, typing.TypeGuard is new in Python 3.10, but
    typing_extensions allows users on previous Python versions to use
    it too.
  * Enable experimentation with new type system PEPs before they are
    accepted and added to the typing module.

New features may be added to typing_extensions as soon as they are
specified in a PEP that has been added to the python/peps repository.
If the PEP is accepted, the feature will then be added to typing for
the next CPython release. No typing PEP has been rejected so far, so
we haven't yet figured out how to deal with that possibility.

Starting with version 4.0.0, typing_extensions uses Semantic Versioning.
The major version is incremented for all backwards-incompatible changes.
Therefore, it's safe to depend on typing_extensions like this:
typing_extensions >=x.y, <(x+1),
where x.y is the first version that includes all features you need.

typing_extensions supports Python versions 3.7 and higher.
In the future, support for older Python versions will be dropped some time
after that version reaches end of life.

%prep
%setup -q -n typing_extensions-%{version}

%if !%{with test}
%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%if %{with test}
%check
pushd src
%pyunittest -v test_typing_extensions
popd
%endif

%if !%{with test}
%files %{python_files}
%license LICENSE
%doc CHANGELOG.md README.md
%{python_sitelib}/typing_extensions.py*
%pycache_only %{python_sitelib}/__pycache__/typing_extensions*
%{python_sitelib}/typing_extensions-%{version}*-info
%endif

%changelog
* Fri Apr 21 2023 dmueller@suse.com
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 mcepl@suse.com
- Make calling of %%{sle15modernpython} optional.
* Thu Feb 23 2023 adrian@suse.de
- update to version 4.5.0
  Details can be found here: https://pypi.org/project/typing-extensions/4.5.0/
- obsoletes _typed_dict_test_helper.py hack
* Sun Nov 20 2022 code@bnavigator.de
- Back to multibuild: remove python-testsuite from buildcycle,
  because of setuptools_scm closing it at the other end.
* Mon Oct 24 2022 code@bnavigator.de
- Clean specfile from old cruft.
- Requires Python 3.7+
- Fix testsuite: Must test as module; don't need multibuild.
- Update Summary and Description
* Tue Oct 18 2022 adrian.glaubitz@suse.com
- Update to version 4.4.0
  * Add `typing_extensions.Any` a backport of python 3.11's Any class which is
    subclassable at runtime. (backport from python/cpython#31841, by Shantanu
    and Jelle Zijlstra). Patch by James Hilton-Balfe (@Gobot1234).
  * Add initial support for TypeVarLike `default` parameter, PEP 696.
    Patch by Marc Mueller (@cdce8p).
  * Runtime support for PEP 698, adding `typing_extensions.override`. Patch by
    Jelle Zijlstra.
  * Add the `infer_variance` parameter to `TypeVar`, as specified in PEP 695.
    Patch by Jelle Zijlstra.
* Mon Sep  5 2022 jayvdb@gmail.com
- Add _typed_dict_test_helper.py missing from PyPI release
- Update to v4.3.0
  * Add typing_extensions.NamedTuple, allowing for generic NamedTuples
    on Python <3.11 (backport from python/cpython#92027, by Serhiy Storchaka)
  * Adjust typing_extensions.TypedDict to allow for generic TypedDicts
    on Python <3.11 (backport from python/cpython#27663, by Samodya Abey)
* Wed Apr 20 2022 adrian.glaubitz@suse.com
- Update to version 4.2.0
  * Re-export `typing.Unpack` and `typing.TypeVarTuple` on Python 3.11.
  * Add `ParamSpecArgs` and `ParamSpecKwargs` to `__all__`.
  * Improve "accepts only single type" error messages.
  * Improve the distributed package. Patch by Marc Mueller (@cdce8p).
  * Update `typing_extensions.dataclass_transform` to rename the
    `field_descriptors` parameter to `field_specifiers` and accept
    arbitrary keyword arguments.
  * Add `typing_extensions.get_overloads` and
    `typing_extensions.clear_overloads`, and add registry support to
    `typing_extensions.overload`. Backport from python/cpython#89263.
  * Add `typing_extensions.assert_type`. Backport from bpo-46480.
  * Drop support for Python 3.6. Original patch by Adam Turner (@AA-Turner).
- from version 4.1.1
  * Fix importing `typing_extensions` on Python 3.7.0 and 3.7.1. Original
    patch by Nikita Sobolev (@sobolevn).
- from version 4.1.0
  * Runtime support for PEP 646, adding `typing_extensions.TypeVarTuple`
    and `typing_extensions.Unpack`.
  * Add interaction of `Required` and `NotRequired` with `__required_keys__`,
    `__optional_keys__` and `get_type_hints()`. Patch by David Cabot (@d-k-bo).
  * Runtime support for PEP 675 and `typing_extensions.LiteralString`.
  * Add `Never` and `assert_never`. Backport from bpo-46475.
  * `ParamSpec` args and kwargs are now equal to themselves. Backport from
    bpo-46676. Patch by Gregory Beauregard (@GBeauregard).
  * Add `reveal_type`. Backport from bpo-46414.
  * Runtime support for PEP 681 and `typing_extensions.dataclass_transform`.
  * `Annotated` can now wrap `ClassVar` and `Final`. Backport from
    bpo-46491. Patch by Gregory Beauregard (@GBeauregard).
  * Add missed `Required` and `NotRequired` to `__all__`. Patch by
    Yuri Karabas (@uriyyo).
  * The `@final` decorator now sets the `__final__` attribute on the
    decorated object to allow runtime introspection. Backport from
    bpo-46342.
  * Add `is_typeddict`. Patch by Chris Moradi (@chrismoradi) and James
    Hilton-Balfe (@Gobot1234).
- from version 4.0.1
  * Fix broken sdist in release 4.0.0. Patch by Adam Turner (@AA-Turner).
  * Fix equality comparison for `Required` and `NotRequired`. Patch by
    Jelle Zijlstra (@jellezijlstra).
  * Fix usage of `Self` as a type argument. Patch by Chris Wesseling
    (@CharString) and James Hilton-Balfe (@Gobot1234).
- from version 4.0.0
  * Starting with version 4.0.0, typing_extensions uses Semantic Versioning.
    See the README for more information.
  * Dropped support for Python versions 3.5 and older, including Python 2.7.
  * Simplified backports for Python 3.6.0 and newer. Patch by Adam Turner (@AA-Turner).
  * Added in version 4.0.0
    + Runtime support for PEP 673 and `typing_extensions.Self`. Patch by
    James Hilton-Balfe (@Gobot1234).
    + Runtime support for PEP 655 and `typing_extensions.Required` and `NotRequired`.
    Patch by David Foster (@davidfstr).
  * Removed in version 4.0.0
    The following non-exported but non-private names have been removed as they are
    unneeded for supporting Python 3.6 and newer.
    + TypingMeta
    + OLD_GENERICS
    + SUBS_TREE
    + HAVE_ANNOTATED
    + HAVE_PROTOCOLS
    + V_co
    + VT_co
- Switch build system from setuptools to pyproject.toml
- Update BuildRequires from pyproject.toml
- Update execution path for testsuite script
* Sat Nov 13 2021 dmueller@suse.com
- Update to 3.10.0.2:
  * Docs improvements
  * Fixes crash  and _GenericAlias import
  * Support most use cases for PEP 612 with Generic
* Mon Jul 12 2021 mmachova@suse.com
- Update to 3.10.0.0
  * Implement TypeGuard (PEP 649)
  * backport ParamSpecArgs/Kwargs
  * Fixed required/optional keys with old-style TypedDict
  * Bring in protocol’s __init__ behaviour same like in python > 3.8
  * Support PEP 612 in typing_extensions (Python 3)
  * Add OrderedDict to typing_extensions
* Tue Jan 12 2021 code@bnavigator.de
- Test in separate multibuild flavor to break depcycles with full
  python stdlib
* Tue Jan 12 2021 code@bnavigator.de
- clean requirements specifications for python flavors
* Sun Dec 20 2020 dmueller@suse.com
- add transitional typing-extensions provides
* Wed Nov  4 2020 mcepl@suse.com
- Use python_module macro for BuildRequires when available.
* Thu Oct 15 2020 dmueller@suse.com
- update to version 3.7.4.3:
  * enables PEP 613 Typealias to typing_extensions
  * Fix tests for Python 3.9
* Mon Apr  6 2020 mcalabkova@suse.com
- update to version 3.7.4.2
  * official support for Python 3.8 and 3.9
* Thu Mar 12 2020 tchvatal@suse.com
- Fix build without python2 available
* Wed Nov  6 2019 lars@linux-schulserver.de
- Update to version 3.7.4.1:
  + Fix isinstance() with generic protocol subclasses after subscripting
  + Fix tests for non-default interpreters
  + Use environment marker to specify typing dependency
  + Fix unions of protocols on Python 2
* Sun Jul 21 2019 sebix+novell.com@sebix.at
- Update to version 3.7.4:
  - No changelog available.
- Drop test-sys-executable.patch, merged upstream.
* Sat Mar  2 2019 tchvatal@suse.com
- Rebase the patch to the current git state
* Sat Mar  2 2019 jayvdb@gmail.com
- Add support for Python <3.5, using upstream commit as
  test-sys-executable.patch to fix the tests, replacing custom sed.
- Remove unnecessary buid dependency on pytest and pytest-xdist
* Thu Feb 28 2019 tchvatal@suse.com
- Drop the old tarball
* Thu Feb 28 2019 jayvdb@gmail.com
- Replace test_modules.tar.gz with python-testsuite
- Remove fix_tests.patch which is half fixing test_modules.tar.gz,
  and the other half is replaced with a less brittle sed.
- Remove unnecessary build dependencies
- Update to 3.7.2
  * Pass *args and **kwargs to superclass in Generic.__new__
  * Fix for issue #524
  * Fix typing_extensions to support PEP 560
  * Add annotations to NamedTuple children __new__ constructors
  * Add missing 'NoReturn' to __all__ in typing.py
  * Backport Generic.__new__ fix
  * Fix IO.closed to be property
  * Add Final to typing_extensions
  * Fix instance/subclass checks of functions against runtime protocols
  * Add Literal[...] types to typing_extensions
* Tue Oct 23 2018 mcepl@suse.com
- Initial effort to package typing_extensions-3.6.6
